==> kita2_1.90.0.orig.tar.gz: kita2-1.90.0/board.rb <==
# Copyright (c) 2008 Hideki Ikemoto
#
# Permission is hereby granted, free of charge, to any person obtaining
# a copy of this software and associated documentation files (the
# "Software"), to deal in the Software without restriction, including
# without limitation the rights to use, copy, modify, merge, publish,
# distribute, sublicense, and/or sell copies of the Software, and to
# permit persons to whom the Software is furnished to do so, subject to
# the following conditions:
#
# The above copyright notice and this permission notice shall be
# included in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
# NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
# LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
# OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
# WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

require 'singleton'

class Board
  attr_reader :url, :title

  def initialize(url, title)
    @url = url
    @title = title
  end
end

class BoardGroup
  attr_reader :name, :list

  def initialize(name)
    @name = name
    @list = []
  end

  def push(board)
    @list.push(board)
  end
end

class BoardManager
  include Singleton

  def initialize
    @name_hash = {}
  end

  def register(url, name)
    @name_hash[url] = name
  end

  def get_name(url)
    @name_hash[url]
  end
end

==> kita2_1.90.4.orig.tar.gz: kita2-1.90.4/board.rb <==
# Copyright (c) 2008 Hideki Ikemoto
#
# Permission is hereby granted, free of charge, to any person obtaining
# a copy of this software and associated documentation files (the
# "Software"), to deal in the Software without restriction, including
# without limitation the rights to use, copy, modify, merge, publish,
# distribute, sublicense, and/or sell copies of the Software, and to
# permit persons to whom the Software is furnished to do so, subject to
# the following conditions:
#
# The above copyright notice and this permission notice shall be
# included in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
# NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
# LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
# OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
# WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

require 'singleton'

class Board
  attr_reader :url, :title

  def initialize(url, title)
    @url = url
    @title = title
  end
end

class BoardGroup
  attr_reader :name, :list

  def initialize(name)
    @name = name
    @list = []
  end

  def push(board)
    @list.push(board)
  end
end

class BoardManager
  include Singleton

  def initialize
    @name_hash = {}
    @url_hash = {}
  end

  def register_name(url, name)
    @name_hash[url] = name
  end

  def register_url(type, id, url)
    if @url_hash.member?([type, id])
      false
    else
      @url_hash[[type, id]] = url
      true
    end
  end

  def get_name(url)
    @name_hash[url]
  end

  def get_url(type, id)
    @url_hash[[type, id]]
  end
end
